@@ -1,11 +1,11 @@
 package org.codehaus.plexus.compiler.eclipse;
 
-import java.util.Arrays;
-import java.util.Collection;
-
 import org.codehaus.plexus.compiler.AbstractCompilerTest;
 import org.codehaus.plexus.compiler.CompilerConfiguration;
 
+import java.util.Arrays;
+import java.util.Collection;
+
 public class EclipseCompilerErrorsAsWarningsTest extends AbstractCompilerTest
 {
 
@@ -39,9 +39,14 @@ public class EclipseCompilerErrorsAsWarningsTest extends AbstractCompilerTest
 
     protected Collection<String> expectedOutputFiles()
     {
-        return Arrays.asList( new String[] { "org/codehaus/foo/Deprecation.class",
-            "org/codehaus/foo/ExternalDeps.class", "org/codehaus/foo/Person.class",
-            "org/codehaus/foo/ReservedWord.class", "org/codehaus/foo/Bad.class",
-            "org/codehaus/foo/UnknownSymbol.class", "org/codehaus/foo/RightClassname.class" } );
+        return Arrays.asList( new String[] {
+            "org/codehaus/foo/Deprecation.class",
+            "org/codehaus/foo/ExternalDeps.class",
+            "org/codehaus/foo/Person.class",
+            "org/codehaus/foo/ReservedWord.class",
+            //"org/codehaus/foo/Bad.class",             // This one has no class file generated as it's one big issue
+            //"org/codehaus/foo/UnknownSymbol.class",
+            //"org/codehaus/foo/RightClassname.class"
+        });
     }
 }
