@@ -63,11 +63,13 @@ import java.util.StringTokenizer;
 import java.util.concurrent.CopyOnWriteArrayList;
 
 import org.codehaus.plexus.compiler.AbstractCompiler;
+import org.codehaus.plexus.compiler.Compiler;
 import org.codehaus.plexus.compiler.CompilerConfiguration;
 import org.codehaus.plexus.compiler.CompilerException;
 import org.codehaus.plexus.compiler.CompilerMessage;
 import org.codehaus.plexus.compiler.CompilerOutputStyle;
 import org.codehaus.plexus.compiler.CompilerResult;
+import org.codehaus.plexus.component.annotations.Component;
 import org.codehaus.plexus.util.FileUtils;
 import org.codehaus.plexus.util.Os;
 import org.codehaus.plexus.util.StringUtils;
@@ -80,9 +82,9 @@ import org.codehaus.plexus.util.cli.Commandline;
  * @author <a href="mailto:matthew.pocock@ncl.ac.uk">Matthew Pocock</a>
  * @author <a href="mailto:joerg.wassmer@web.de">J&ouml;rg Wa&szlig;mer</a>
  * @author Others
- * @plexus.component role="org.codehaus.plexus.compiler.Compiler"
- * role-hint="javac"
+ *
  */
+@Component( role = Compiler.class, hint = "javac ")
 public class JavacCompiler
     extends AbstractCompiler
 {
@@ -173,7 +175,7 @@ public class JavacCompiler
             {
                 // use fqcn to prevent loading of the class on 1.5 environment !
                 result =
-                    org.codehaus.plexus.compiler.javac.JavaxToolsCompiler.compileInProcess( args, config, sourceFiles );
+                    inProcessCompiler().compileInProcess( args, config, sourceFiles );
             }
             else
             {
@@ -184,6 +186,11 @@ public class JavacCompiler
         return result;
     }
 
+	protected InProcessCompiler inProcessCompiler()
+	{
+		return new org.codehaus.plexus.compiler.javac.JavaxToolsCompiler();
+	}
+
     protected static boolean isJava16()
     {
         try
@@ -205,7 +212,7 @@ public class JavacCompiler
 
     public static String[] buildCompilerArguments( CompilerConfiguration config, String[] sourceFiles )
     {
-        List<String> args = new ArrayList<String>();
+        List<String> args = new ArrayList<>();
 
         // ----------------------------------------------------------------------
         // Set output
@@ -563,11 +570,7 @@ public class JavacCompiler
 
             messages = parseModernStream( returnCode, new BufferedReader( new StringReader( out.getOutput() ) ) );
         }
-        catch ( CommandLineException e )
-        {
-            throw new CompilerException( "Error while executing the external compiler.", e );
-        }
-        catch ( IOException e )
+        catch ( CommandLineException | IOException e )
         {
             throw new CompilerException( "Error while executing the external compiler.", e );
         }
@@ -663,7 +666,7 @@ public class JavacCompiler
     static List<CompilerMessage> parseModernStream( int exitCode, BufferedReader input )
         throws IOException
     {
-        List<CompilerMessage> errors = new ArrayList<CompilerMessage>();
+        List<CompilerMessage> errors = new ArrayList<>();
 
         String line;
 
